function [ Kl,Cl,Ml ] = elmt11( local_data )
%elmt11: 1-D Bar element for 2nd order PDE in x1
% (Spring element, linear flow element, etc.)
%
%Element subroutine to construct local stiffness matrix from local data
%
%  local_data.mater = [elt# Hyd.Cond Area Capacitance prop4 prop5 ] For material type
%
%  local_data.coords = [ x1 of node 1;
%                        x1 of node 2]
%
%  local_data.dofs   = [ dof1 dof2 ] Global dof referenced to local dofs
%
  Kl = zeros(2,2)
  Cl = zeros(2,2)
  Ml = zeros(2,2)
%
  cond   = local_data.mater(1,2);
  area   = local_data.mater(1,3);
  capacitance = local_data.mater(1,4);
  length = abs(local_data.coords(2,1)-local_data.coords(1,1));
%-------------------------------- Evaluate matrix coefficients
  coef   = area * cond /length;
%-------------------------------- Evaluate stiffness matrix
  Kl = [ coef -coef;   -coef  coef ];
%-------------------------------- Evaluate capacitance matrix
  Cl = (area*length*capacitance/2) * [ 1 0; 0 1 ];
